@@ -1,4 +1,5 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -73,6 +74,12 @@ class MemPager;
  * @author David Sugar <dyfet@ostel.com>
  * @short Generic string class.
  */
+
+/* can't put default value in friend */
+
+class  String;
+__EXPORT std::istream &getline(std::istream &is, String &str, char delim = '\n', size_t size = 0);
+
 class __EXPORT String
 {
 protected:
@@ -730,7 +737,7 @@ public:
 	 * @param delim deliminator to use.
 	 * @param size optional size limitor.
 	 */
-	friend __EXPORT std::istream &getline(std::istream &is, String &str, char delim = '\n', size_t size = 0);
+	friend __EXPORT std::istream &getline(std::istream &is, String &str, char delim, size_t size);
 
 	/**
 	 * Stream the content of our string variable directly to a C++
